// Copyright 2018 Google LLC. All Rights Reserved.
/*
  Copyright (C) 2007 Steven L. Scott

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
*/

#ifndef BOOM_TRUN_GAMMA_HPP
#define BOOM_TRUN_GAMMA_HPP

#include "distributions/rng.hpp"

namespace BOOM {
  // Density of the truncated Gamma(a,b) distribution with support >= cut.
  double dtrun_gamma(double x, double a, double b, double cut, bool logscale);

  // Returns a draw from the truncated Gamma(a,b) distribution with
  // support >= cut.
  double rtrun_gamma(double a, double b, double cut, unsigned n = 5);
  double rtrun_gamma_mt(RNG &, double a, double b, double cut, unsigned n = 5);
}  // namespace BOOM
#endif  // BOOM_TRUN_GAMMA_HPP
